using System.Text.Json;
using Gep.Api.Util;

namespace Gep.Api.Demo
{
    /// <summary>
    /// 客户入网API示例
    /// </summary>
    public class Agent
    {
        /// <summary>
        /// 文件上传
        /// </summary>
        public static void UploadFile()
        {
            string path = "/api/agent/common/file/upload-file";
            string filePath = StringUtil.GetCurrentPath()+"\\Cert\\test.jpg";
            FileItem fileItem = new FileItem(filePath);
            Dictionary<string, FileItem> fileItemDict = new()
            {
                { "file", fileItem }
            };
            
            Dictionary<string, string> dataContent = new Dictionary<string, string>
            {
                { "userNo", "5181240322000274308" },
                { "fileName", fileItem.GetFileName() },
                { "fileMd5encryption", fileItem.GetFileMD5() },
                { "fileType", "ID_FRONT_REAL_NAME" }
            };
            ApiRequest.AgentPost(path, dataContent, fileItemDict);
        }
        
        /// <summary>
        /// 创建用户
        /// </summary>
        public static void CreateUser()
        {
            string path = "/api/agent/user/createUser";
            Dictionary<string, string> dataContent = new Dictionary<string, string>
            {
                { "userNo", "5181240322000274308" },
                { "email", "mucang@baofoo.com" }
            };
            ApiRequest.AgentPost(path, dataContent);
        }
        
        /// <summary>
        /// 新增实名
        /// </summary>
        public static void CertificationAdd()
        {
            string path = "/api/agent/user/certification-add";
            Dictionary<string, string> dataContentMap = new Dictionary<string, string>
            {
                { "userNo", "5181240322000274308" },
                { "userType", "2" },// 1-境内个人 2-境内企业 3-香港企业 5-其他地区企业
                { "callBackUrl", "http://10.0.60.55:8083/gep-agent-demo-java/Notify/agent" }
            };
            Dictionary<string, object> informationMap = new Dictionary<string, object>();

                if (dataContentMap["userType"].Equals("1")) // 1-境内个人
                {
                    informationMap["idFront"] = 13331433;
                    informationMap["idReverse"] = 13331435;
                    informationMap["idHold"] = 13331436;
                    informationMap["idNo"] = "421000195710071340";
                    informationMap["name"] = "木木";
                    informationMap["legalCertExpiryDate"] = "2050-01-01";
                    informationMap["birthDate"] = "2000-01-01";
                    informationMap["province"] = "210000_辽宁省";
                    informationMap["city"] = "210200_大连市";
                    informationMap["area"] = "210202_中山区";
                    informationMap["address"] = "市区";
                    informationMap["postCode"] = "";
                }
                else if (dataContentMap["userType"].Equals("2")) // 2-境内企业
                {
                    informationMap["license"] = 13331433;
                    informationMap["licenseNo"] = "913101045680189671";
                    informationMap["name"] = "全球有限互联公司";
                    informationMap["enName"] = "Global limited Internet company";
                    informationMap["companyType"] = "有限责任公司";
                    informationMap["registerProvince"] = "210000_辽宁省";
                    informationMap["registerCity"] = "210200_大连市";
                    informationMap["registerArea"] = "210202_中山区";
                    informationMap["registerAddress"] = "某个地方";
                    informationMap["legalRepresentative"] = "阿木木";
                    informationMap["registerAmt"] = "100";
                    informationMap["registerCcy"] = "CNY";
                    informationMap["registerDate"] = "2000-01-01";
                    informationMap["endDate"] = "2099-01-01";
                    informationMap["managementScope"] = "经营范围";
                    informationMap["province"] = "210000_辽宁省";
                    informationMap["city"] = "210200_大连市";
                    informationMap["area"] = "210202_中山区";
                    informationMap["address"] = "某个地方";
                    informationMap["industryId"] = "0313";
                    informationMap["economyId"] = "159";
                    informationMap["legalIdType"] = 2;
                    informationMap["legalIdFront"] = 13331435;
                    informationMap["legalIdReverse"] = null;
                    informationMap["legalIdHold"] = 13331436;
                    informationMap["legalIdNo"] = "421000195710071340";
                    informationMap["legalName"] = "阿木木";
                    informationMap["legalBirthDate"] = "2000-01-01";
                    informationMap["legalCertExpiryDate"] = "2050-01-01";
                    informationMap["legalProvince"] = "210000_辽宁省";
                    informationMap["legalCity"] = "210200_大连市";
                    informationMap["legalArea"] = "210202_中山区";
                    informationMap["legalAddress"] = "一个村庄";
                    informationMap["legalCountryCode"] = "CHN";
                    informationMap["beneficiaryIdType"] = new int[] { 1 };
                    informationMap["beneficiaryIdFront"] = new int[] { 13331435 };
                    informationMap["beneficiaryIdReverse"] = new int[] { 13331436 };
                    informationMap["beneficiaryIdNo"] = new string[] { "421000195710071340" };
                    informationMap["beneficiaryName"] = new string[] { "阿木木" };
                    informationMap["beneficiaryBirthDate"] = new string[] { "2000-01-01" };
                    informationMap["beneficiaryCertExpiryDate"] = new string[] { "2050-01-01" };
                    informationMap["beneficiaryProvince"] = new string[] { "210000_辽宁省" };
                    informationMap["beneficiaryCity"] = new string[] { "210200_大连市" };
                    informationMap["beneficiaryArea"] = new string[] { null };
                    informationMap["beneficiaryAddress"] = new string[] { "一个村庄" };
                    informationMap["beneficiaryShareholderRatio"] = new int[] { 100 };
                    informationMap["beneficiaryCountry"] = new string[] { "CHN" };
                }
                else if (dataContentMap["userType"].Equals("3")) // 3-香港企业
                {
                    informationMap["businessRegister"] = 13331433;
                    informationMap["declarationForm"] = 13331433;
                    informationMap["incorporationForm"] = 13331433;
                    informationMap["orgRegister"] = 13331433;
                    informationMap["stockCertificate"] = 13331433;
                    informationMap["name"] = "全球有限互联公司";
                    informationMap["enName"] = "QU QIU YOU XIAN HU LIAN";
                    informationMap["orgRegisterNo"] = "11000001";
                    informationMap["businessRegisterNo"] = "11000002";
                    informationMap["businessRegisterExpiryDate"] = "2025-06-01";
                    informationMap["registerDate"] = "2000-01-01";
                    informationMap["registerAmt"] = "100";
                    informationMap["registerProvince"] = "210000_辽宁省";
                    informationMap["registerCity"] = "210200_大连市";
                    informationMap["registerArea"] = "210202_中山区";
                    informationMap["registerAddress"] = "某个地方";
                    informationMap["province"] = "210000_辽宁省";
                    informationMap["city"] = "210200_大连市";
                    informationMap["area"] = "210202_中山区";
                    informationMap["address"] = "某个地方";
                    informationMap["directorIdType"] = "1";
                    informationMap["directorIdFront"] = 13331433;
                    informationMap["directorIdReverse"] = 13331433;
                    informationMap["directorIdHold"] = 13331433;
                    informationMap["directorIdNo"] = "421000195710071340";
                    informationMap["directorName"] = "阿木木";
                    informationMap["directorBirthDate"] = "1988-06-06";
                    informationMap["directorCertExpiryDate"] = "2042-01-01";
                    informationMap["directorProvince"] = "210000_辽宁省";
                    informationMap["directorCity"] = "210200_大连市";
                    informationMap["directorArea"] = "210202_中山区";
                    informationMap["directorAddress"] = "某个地方";
                    informationMap["directorCountryCode"] = "CHN";

                    informationMap["beneficiaryIdType"] = new int[] { 1 };
                    informationMap["beneficiaryIdFront"] = new int[] { 13331435 };
                    informationMap["beneficiaryIdReverse"] = new int[] { 13331436 };
                    informationMap["beneficiaryIdNo"] = new string[] { "421000195710071340" };
                    informationMap["beneficiaryName"] = new string[] { "阿木木" };
                    informationMap["beneficiaryBirthDate"] = new string[] { "2000-01-01" };
                    informationMap["beneficiaryCertExpiryDate"] = new string[] { "2050-01-01" };
                    informationMap["beneficiaryProvince"] = new string[] { "210000_辽宁省" };
                    informationMap["beneficiaryCity"] = new string[] { "210200_大连市" };
                    informationMap["beneficiaryArea"] = new string[] { null };
                    informationMap["beneficiaryAddress"] = new string[] { "一个村庄" };
                    informationMap["beneficiaryShareholderRatio"] = new int[] { 100 };
                    informationMap["beneficiaryCountry"] = new string[] { "NZL" };
                }
                else if (dataContentMap["userType"].Equals("5")) // 5-其他地区企业
                {
                    informationMap["orgRegister"] = 12312311;
                    informationMap["otherAccessories"] = 12312311;
                    informationMap["registerCountry"] = "USA";
                    informationMap["name"] = "全球有限互联公司1";
                    informationMap["enName"] = "QU QIU YOU XIAN HU LIAN1";
                    informationMap["orgRegisterNo"] = "1100000111";
                    informationMap["registerDate"] = "2000-01-01";
                    informationMap["registerAmt"] = "100";
                    informationMap["registerProvince"] = "210000_辽宁省";
                    informationMap["registerCity"] = "210200_大连市";
                    informationMap["registerArea"] = "210202_中山区";
                    informationMap["registerAddress"] = "某个地方";
                    informationMap["province"] = "210000_辽宁省";
                    informationMap["city"] = "210200_大连市";
                    informationMap["area"] = "210202_中山区";
                    informationMap["address"] = "某个地方";
                    informationMap["postCode"] = "12345";

                    informationMap["directorIdType"] = new int[] { 2 };
                    informationMap["directorIdFront"] = new int[] { 13331433 };
                    informationMap["directorIdReverse"] = new int[] { 13331433 };
                    informationMap["directorIdHold"] = new int[] { 13331433 };
                    informationMap["directorIdNo"] = new string[] { "421000195710071340" };
                    informationMap["directorName"] = new string[] { "阿木木" };
                    informationMap["directorBirthDate"] = new string[] { "1988-06-06" };
                    informationMap["directorCertExpiryDate"] = new string[] { "2042-01-01" };
                    informationMap["directorProvince"] = new string[] { "210000_辽宁省" };
                    informationMap["directorCity"] = new string[] { "210200_大连市" };
                    informationMap["directorArea"] = new string[] { "210202_中山区" };
                    informationMap["directorAddress"] = new string[] { "某个地方" };
                    informationMap["directorCountryCode"] = new string[] { "CHN" };

                    informationMap["beneficiaryIdType"] = new int[] { 1 };
                    informationMap["beneficiaryIdFront"] = new int[] { 13331435 };
                    informationMap["beneficiaryIdReverse"] = new int[] { 13331436 };
                    informationMap["beneficiaryIdNo"] = new string[] { "421000195710071340" };
                    informationMap["beneficiaryName"] = new string[] { "阿木木" };
                    informationMap["beneficiaryBirthDate"] = new string[] { "2000-01-01" };
                    informationMap["beneficiaryCertExpiryDate"] = new string[] { "2050-01-01" };
                    informationMap["beneficiaryProvince"] = new string[] { "210000_辽宁省" };
                    informationMap["beneficiaryCity"] = new string[] { "210200_大连市" };
                    informationMap["beneficiaryArea"] = new string[] { null };
                    informationMap["beneficiaryAddress"] = new string[] { "一个村庄" };
                    informationMap["beneficiaryShareholderRatio"] = new int[] { 100 };
                    informationMap["beneficiaryCountry"] = new string[] { "CHN" };
                }
                dataContentMap.Add("information", JsonSerializer.Serialize(informationMap));
            ApiRequest.AgentPost(path, dataContentMap);
        }
        /// <summary>
        /// 修改实名：认证失败或证件过期时，调用修改实名接口重新提交认证信息
        /// </summary>
        public static void CertificationEdit()
        {
            string path = "/api/agent/user/certification-edit";
            Dictionary<string, string> dataContentMap = new Dictionary<string, string>
            {
                { "userNo", "5181240322000274308" },
                { "userType", "2" },// 1-境内个人 2-境内企业 3-香港企业 5-其他地区企业
                { "callBackUrl", "http://10.0.60.55:8083/gep-agent-demo-java/Notify/agent" }
            };
            Dictionary<string, object> informationMap = new Dictionary<string, object>();

            if (dataContentMap["userType"].Equals("1")) // 1-境内个人
                {
                    informationMap["idFront"] = 13331433;
                    informationMap["idReverse"] = 13331435;
                    informationMap["idHold"] = 13331436;
                    informationMap["idNo"] = "421000195710071340";
                    informationMap["name"] = "木木";
                    informationMap["legalCertExpiryDate"] = "9999-01-01";
                    informationMap["birthDate"] = "2000-01-01";
                    informationMap["province"] = "210000_辽宁省";
                    informationMap["city"] = "210200_大连市";
                    informationMap["area"] = "210202_中山区";
                    informationMap["address"] = "市区";
                    informationMap["postCode"] = "";
                }
                else if (dataContentMap["userType"].Equals("2")) // 2-境内企业
                {
                    informationMap["license"] = 13331433;
                    informationMap["licenseNo"] = "913101045680189677";
                    informationMap["name"] = "全球有限互联公司";
                    informationMap["enName"] = "QU QIU YOU XIAN HU LIAN";
                    informationMap["companyType"] = "有限责任公司";
                    informationMap["registerProvince"] = "210000_辽宁省";
                    informationMap["registerCity"] = "210200_大连市";
                    informationMap["registerArea"] = "210202_中山区";
                    informationMap["registerAddress"] = "某个地方";
                    informationMap["legalRepresentative"] = "阿木木";
                    informationMap["registerAmt"] = "100";
                    informationMap["registerCcy"] = "CNY";
                    informationMap["registerDate"] = "2000-01-01";
                    informationMap["endDate"] = "9999-01-01";
                    informationMap["managementScope"] = "经营范围";
                    informationMap["province"] = "210000_辽宁省";
                    informationMap["city"] = "210200_大连市";
                    informationMap["area"] = "210202_中山区";
                    informationMap["address"] = "某个地方";
                    informationMap["industryId"] = "0313";
                    informationMap["economyId"] = "159";
                    informationMap["legalIdType"] = "2";
                    informationMap["legalIdFront"] = 13331435;
                    informationMap["legalIdReverse"] = null;
                    informationMap["legalIdHold"] = 13331436;
                    informationMap["legalIdNo"] = "421000195710071340";
                    informationMap["legalName"] = "阿木木";
                    informationMap["legalBirthDate"] = "2000-01-01";
                    informationMap["legalCertExpiryDate"] = "9999-01-01";
                    informationMap["legalProvince"] = "210000_辽宁省";
                    informationMap["legalCity"] = "210200_大连市";
                    informationMap["legalArea"] = "210202_中山区";
                    informationMap["legalAddress"] = "一个村庄";
                    informationMap["legalCountryCode"] = "CHN";
                    informationMap["beneficiaryIdType"] = new int[] { 1 };
                    informationMap["beneficiaryIdFront"] = new int[] { 13331435 };
                    informationMap["beneficiaryIdReverse"] = new int[] { 13331436 };
                    informationMap["beneficiaryIdNo"] = new string[] { "421000195710071340" };
                    informationMap["beneficiaryName"] = new string[] { "阿木木" };
                    informationMap["beneficiaryBirthDate"] = new string[] { "2000-01-01" };
                    informationMap["beneficiaryCertExpiryDate"] = new string[] { "9999-01-01" };
                    informationMap["beneficiaryProvince"] = new string[] { "210000_辽宁省" };
                    informationMap["beneficiaryCity"] = new string[] { "210200_大连市" };
                    informationMap["beneficiaryArea"] = new string[] { null };
                    informationMap["beneficiaryAddress"] = new string[] { "一个村庄" };
                    informationMap["beneficiaryShareholderRatio"] = new int[] { 100 };
                    informationMap["beneficiaryCountry"] = new string[] { "CHN" };
                }
                else if (dataContentMap["userType"].Equals("3")) // 3-香港企业
                {
                    informationMap["businessRegister"] = 13331433;
                    informationMap["declarationForm"] = 13331433;
                    informationMap["incorporationForm"] = 13331433;
                    informationMap["orgRegister"] = 13331433;
                    informationMap["stockCertificate"] = 13331433;
                    informationMap["name"] = "全球有限互联公司";
                    informationMap["enName"] = "QU QIU YOU XIAN HU LIAN";
                    informationMap["orgRegisterNo"] = "11000001";
                    informationMap["businessRegisterNo"] = "11000002";
                    informationMap["businessRegisterExpiryDate"] = "2025-06-01";
                    informationMap["registerDate"] = "2000-01-01";
                    informationMap["registerAmt"] = "100";
                    informationMap["registerProvince"] = "210000_辽宁省";
                    informationMap["registerCity"] = "210200_大连市";
                    informationMap["registerArea"] = "210202_中山区";
                    informationMap["registerAddress"] = "某个地方";
                    informationMap["province"] = "210000_辽宁省";
                    informationMap["city"] = "210200_大连市";
                    informationMap["area"] = "210202_中山区";
                    informationMap["address"] = "某个地方";
                    informationMap["directorIdType"] = "1";
                    informationMap["directorIdFront"] = 13331433;
                    informationMap["directorIdReverse"] = 13331433;
                    informationMap["directorIdHold"] = 13331433;
                    informationMap["directorIdNo"] = "421000195710071340";
                    informationMap["directorName"] = "阿木木";
                    informationMap["directorBirthDate"] = "1988-06-06";
                    informationMap["directorCertExpiryDate"] = "2042-01-01";
                    informationMap["directorProvince"] = "210000_辽宁省";
                    informationMap["directorCity"] = "210200_大连市";
                    informationMap["directorArea"] = "210202_中山区";
                    informationMap["directorAddress"] = "某个地方";
                    informationMap["directorCountryCode"] = "CHN";

                    informationMap["beneficiaryIdType"] = new int[] { 1 };
                    informationMap["beneficiaryIdFront"] = new int[] { 13331435 };
                    informationMap["beneficiaryIdReverse"] = new int[] { 13331436 };
                    informationMap["beneficiaryIdNo"] = new string[] { "421000195710071340" };
                    informationMap["beneficiaryName"] = new string[] { "阿木木" };
                    informationMap["beneficiaryBirthDate"] = new string[] { "2000-01-01" };
                    informationMap["beneficiaryCertExpiryDate"] = new string[] { "2050-01-01" };
                    informationMap["beneficiaryProvince"] = new string[] { "210000_辽宁省" };
                    informationMap["beneficiaryCity"] = new string[] { "210200_大连市" };
                    informationMap["beneficiaryArea"] = new string[] { null };
                    informationMap["beneficiaryAddress"] = new string[] { "一个村庄" };
                    informationMap["beneficiaryShareholderRatio"] = new int[] { 100 };
                    informationMap["beneficiaryCountry"] = new string[] { "CHN" };
                }
                else if (dataContentMap["userType"].Equals("5")) // 5-其他地区企业
                {
                    informationMap["orgRegister"] = 123123;
                    informationMap["otherAccessories"] = 123123;
                    informationMap["registerCountry"] = "USA";
                    informationMap["name"] = "全球有限互联公司";
                    informationMap["enName"] = "QU QIU YOU XIAN HU LIAN";
                    informationMap["orgRegisterNo"] = "11000001";
                    informationMap["registerDate"] = "2000-01-01";
                    informationMap["registerAmt"] = "100";
                    informationMap["registerProvince"] = "210000_辽宁省";
                    informationMap["registerCity"] = "210200_大连市";
                    informationMap["registerArea"] = "210202_中山区";
                    informationMap["registerAddress"] = "某个地方";
                    informationMap["province"] = "210000_辽宁省";
                    informationMap["city"] = "210200_大连市";
                    informationMap["area"] = "210202_中山区";
                    informationMap["address"] = "某个地方";
                    informationMap["postCode"] = "12345";

                    informationMap["directorIdType"] = new int[] { 1 };
                    informationMap["directorIdFront"] = new int[] { 13331433 };
                    informationMap["directorIdReverse"] = new int[] { 13331433 };
                    informationMap["directorIdHold"] = new int[] { 13331433 };
                    informationMap["directorIdNo"] = new string[] { "421000195710071340" };
                    informationMap["directorName"] = new string[] { "阿木木" };
                    informationMap["directorBirthDate"] = new string[] { "1988-06-06" };
                    informationMap["directorCertExpiryDate"] = new string[] { "2042-01-01" };
                    informationMap["directorProvince"] = new string[] { "210000_辽宁省" };
                    informationMap["directorCity"] = new string[] { "210200_大连市" };
                    informationMap["directorArea"] = new string[] { "210202_中山区" };
                    informationMap["directorAddress"] = new string[] { "某个地方" };
                    informationMap["directorCountryCode"] = new string[] { "CHN" };

                    informationMap["beneficiaryIdType"] = new int[] { 1 };
                    informationMap["beneficiaryIdFront"] = new int[] { 13331435 };
                    informationMap["beneficiaryIdReverse"] = new int[] { 13331436 };
                    informationMap["beneficiaryIdNo"] = new string[] { "421000195710071340" };
                    informationMap["beneficiaryName"] = new string[] { "阿木木" };
                    informationMap["beneficiaryBirthDate"] = new string[] { "2000-01-01" };
                    informationMap["beneficiaryCertExpiryDate"] = new string[] { "2050-01-01" };
                    informationMap["beneficiaryProvince"] = new string[] { "210000_辽宁省" };
                    informationMap["beneficiaryCity"] = new string[] { "210200_大连市" };
                    informationMap["beneficiaryArea"] = new string[] { null };
                    informationMap["beneficiaryAddress"] = new string[] { "一个村庄" };
                    informationMap["beneficiaryShareholderRatio"] = new int[] { 100 };
                    informationMap["beneficiaryCountry"] = new string[] { "CHN" };
                }
             
            dataContentMap.Add("information", JsonSerializer.Serialize(informationMap));
            ApiRequest.AgentPost(path, dataContentMap);
        }

        /// <summary>
        /// 实名信息详情
        /// </summary>
        public static void CertificationDetail()
        {
            string path = "/api/agent/user/certification-detail";
            Dictionary<string, string> dataContent = new Dictionary<string, string>
            {
                { "userNo", "5181240322000274308" }
            };
            ApiRequest.AgentPost(path, dataContent);
        }
        
        /// <summary>
        /// 分页查询用户
        /// </summary>
        public static void CertificationPage()
        {
            string path = "/api/agent/user/certification-page";
            Dictionary<string, string> dataContent = new Dictionary<string, string>
            {
                //dataContent.Add("userNo", "5181240322000274308");
                { "beginTime", "2024-03-22" },
                { "endTime", "2024-11-22" },
                { "currentPage", "1" },
                { "pageSize", "10" }
            };
            ApiRequest.AgentPost(path, dataContent);
        }
    }
}